@@ -1,15 +1,12 @@
 "quagam" <-
 function(f,para) { 
+    if(! check.fs(f)) return()
     if(! are.pargam.valid(para)) return()
     ALPHA <- para$para[1] 
     BETA  <- para$para[2] 
-
-    x <- vector(mode="numeric")
-    for(i in seq(1,length(f))) {
-      if(f[i] <= 0 || f[i] >= 1) {
-        warning("argument of function is invalid")
-        return()
-      }
+    n <- length(f)
+    x <- vector(mode="numeric",length=n)
+    for(i in seq(1,n)) {
       if(f[i] == 0) { x[i] <- 0; next }
       x[i] <- qgamma(f[i],ALPHA,scale=BETA)
     }
